@@ -44,6 +44,7 @@
 CEcaIAManager::CEcaIAManager()
 {
   nTimerIDFinished = 0;
+  nTimerIDCurrentPos = 0;
   nMasterPosition = 0;
   rStatus = NotRunning;
   nBufferSize = 1024;
@@ -130,6 +131,16 @@ CEcaIAManager::setBufferSize(int nSize)
 
 /////////////////////////////////////////////////////////////////////////////
 
+QTime
+CEcaIAManager::pos()
+{
+  command("cs-get-position", false);
+
+  return QTime().addMSecs(static_cast<int>(lastFloat()) * 1000);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 CEcaIAManager::slotCreateNewChainsetup(const QString& strChainsetup)
 {
@@ -179,7 +190,8 @@ CEcaIAManager::slotPlay(bool bRecord)
   }
 
   killTimers(); // kill all timers
-  nTimerIDFinished = startTimer(500); // 500-milisecond timer
+  nTimerIDFinished   = startTimer(500); // 500-milisecond timer
+  nTimerIDCurrentPos = startTimer(100); // 100-milisecond timer
 
   if ( bRecord ) {
     rStatus = Recording;
@@ -219,7 +231,8 @@ CEcaIAManager::slotPause()
 void
 CEcaIAManager::slotResume()
 {
-  nTimerIDFinished = startTimer(500); // 500-milisecond timer
+  nTimerIDFinished   = startTimer(500); // 500-milisecond timer
+  nTimerIDCurrentPos = startTimer(100); // 100-milisecond timer
   command("start");
 }
 
@@ -364,7 +377,8 @@ CEcaIAManager::slotMixdown(
   }
 
   killTimers(); // kill all timers
-  nTimerIDFinished = startTimer(500); // 500-milisecond timer
+  nTimerIDFinished   = startTimer(500); // 500-milisecond timer
+  nTimerIDCurrentPos = startTimer(100); // 100-milisecond timer
 
   rStatus = Mixing;
 
@@ -451,7 +465,7 @@ CEcaIAManager::slotRemoveChain(const QString& strTrackName)
 void
 CEcaIAManager::slotRemoveChain(int nID)
 {
-  if ( (nID < 0) || (nID >= vTrackChains.size()) ) {
+  if ( (nID < 0) || (nID >= static_cast<int>(vTrackChains.size())) ) {
     return;
   }
 
@@ -987,11 +1001,14 @@ void
 CEcaIAManager::timerEvent(QTimerEvent* TimerEvent)
 {
   if ( TimerEvent->timerId() == nTimerIDFinished ) {
-    if ( engineStatus() == Finished ) {
+    if ( engineStatus() == Finished ) { // when finished
       killTimer(nTimerIDFinished);
       doDetailStopped();
     }
+  } else if ( TimerEvent->timerId() == nTimerIDCurrentPos ) {
+    emit moved(pos());
   }
+
   QObject::timerEvent(TimerEvent);
 }
 
@@ -1008,7 +1025,7 @@ CEcaIAManager::writeEwf(const QString& strTrackName, const QString& strFileName)
 void 
 CEcaIAManager::writeEwf(int nIndex, const QString& strFileName)
 {
-  if ( (nIndex < 0) || (nIndex >= vTrackChains.size()) ) {
+  if ( (nIndex < 0) || (nIndex >= static_cast<int>(vTrackChains.size())) ) {
     return;
   }
 
