@@ -282,6 +282,7 @@ WVoxBase::clearTracks()
   if ( nTrack != 0 ) {
     vVoxTracks.clear();
   }
+  vTrackOrder.clear();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -321,6 +322,16 @@ WVoxBase::removeTrack(const QString& strTrackName)
       SignalMapperLength->removeMappings(vVoxTracks[i]);
 
       VLayoutTracks->remove(vVoxTracks[i]);
+
+      QValueVector<WVoxTrack*>::iterator it = vTrackOrder.begin();
+      while ( it != vTrackOrder.end() ) {
+        if ( (*it) == vVoxTracks[i] ) {
+          vTrackOrder.erase(it);
+          break;
+        }
+        it++;
+      }
+
       delete vVoxTracks[i];
     } else {
       vVoxTracksTmp.push_back(vVoxTracks[i]);
@@ -548,12 +559,34 @@ WVoxBase::setMaxSessionLength(const QTime& time)
 
 /////////////////////////////////////////////////////////////////////////////
 
+CTrackInf
+WVoxBase::trackInfByDisplayOrder(int nID) const
+{
+  // ¤ؤ줺˽ƥ뤵줿ϡ٥
+  if ( vTrackOrder.size() == 0 ) {
+    QValueVector<WVoxTrack*>::const_iterator it = vVoxTracks.begin();
+    while ( it != vVoxTracks.end() ) {
+      vTrackOrder.push_back(*it);
+      it++;
+    }
+  }
+
+  if ( nID < 0 || vTrackOrder.size() <= static_cast<uint>(nID) ) {
+    return CTrackInf();
+  }
+
+  return vTrackOrder[nID]->stateInTrackInf();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxBase::resizeEvent(QResizeEvent* Event)
 {
   QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
   FrameTracks->resize(Event->size().width() - 24, FrameTracks->height());
   while ( it != vVoxTracks.end() ) {
+    (*it)->setMinimumWidth(Event->size().width() - 24);
     (*it)->resize(Event->size().width() - 24, (*it)->height());
     it++;
   }
@@ -606,6 +639,7 @@ WVoxBase::slotChangeState(State state)
     TimeEditProceed->setTime(QTime());
     TimeEditProceed->show();
     LabelProceed->show();
+    TimeEditPosition->setEnabled(false);
   }
   // PAUSE
   else if ( state == Pause ) {
@@ -624,6 +658,7 @@ WVoxBase::slotChangeState(State state)
                false);
       it++;
     }
+    TimeEditPosition->setEnabled(false);
   }
   // STOP
   else if ( state == Stop ) {
@@ -641,6 +676,7 @@ WVoxBase::slotChangeState(State state)
                true);
       it++;
     }
+    TimeEditPosition->setEnabled(true);
   }
 }
 
@@ -691,10 +727,25 @@ WVoxBase::slotChangeTrackOrder(QValueVector<int> vOrder)
   }
 
   // relayout
+  if ( vTrackOrder.size() == 0 ) {
+    QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+    while ( it != vVoxTracks.end() ) {
+      vTrackOrder.push_back(*it);
+      it++;
+    }
+  }
+
   int i;
-  int nCount = vVoxTracks.size();
+  int nCount = vTrackOrder.size();
+  QValueVector<WVoxTrack*> vNewOrder;
   for ( i = 0; i < nCount; i++ ) {
-    VLayoutTracks->addWidget(vVoxTracks[vOrder[i]]);
+    vNewOrder.push_back(vTrackOrder[vOrder[i]]);
+  }
+
+  nCount = vVoxTracks.size();
+  for ( i = 0; i < nCount; i++ ) {
+    VLayoutTracks->addWidget(vNewOrder[i]);
+    vTrackOrder[i] = vNewOrder[i];
   }
 }
 
