@@ -130,6 +130,11 @@ public:
   //! \brief  åκĹꤹ롣
   void setMaxSessionLength(const QTime& time);
 
+  //! \brief  ɽˤʤȥå֤
+  //! \param  nOrder nOrderܤɽƤȥå֤
+  //!         from zero
+  CTrackInf trackInfByDisplayOrder(int nID) const;
+
 protected:
   void resizeEvent(QResizeEvent* Event);
 
@@ -183,6 +188,9 @@ private:
   //! ʹԻ֡
   QTime         timeProceed;
 
+  //! ΤΥ٥
+  mutable QValueVector<WVoxTrack*> vTrackOrder;
+
   //! åȤꡣ
   //! 󥹥ȥ饯Τ߸ƤӽФġ
   void setupWidgets();
