@@ -1020,7 +1020,7 @@ WVoxStorm::slotTrackOrder()
     int i;
     int nCount = VoxBase->getTrackCount();
     for ( i = 0; i < nCount; i++ ) {
-      strl.push_back(VoxBase->getTrackInf(i).strTrackName);
+      strl.push_back(VoxBase->trackInfByDisplayOrder(i).strTrackName);
     }
     dialog.slotSetList(strl);
   }
